from .pubkey_utils import get_pubkey

SYSTEM_PROGRAM = "11111111111111111111111111111111"
SYSTEM_PROGRAM_PUBKEY = get_pubkey(SYSTEM_PROGRAM)
RENT = "SysvarRent111111111111111111111111111111111"
RENT_PUBKEY= get_pubkey(RENT)
TOKEN_PROGRAM_ID = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA"
TOKEN_PROGRAM_ID_PUBKEY = get_pubkey(TOKEN_PROGRAM_ID)
    
PUMP_FUN_GLOBAL = "4wTV1YmiEkRvAtNtsSGPtUrqRYQMe5SKy2uB4Jjaxnjf"
PUMP_FUN_GLOBAL_PUBKEY = get_pubkey(PUMP_FUN_GLOBAL)
PUMP_FUN_FEE_RECIPIENT = "CebN5WGQ4jvEPvsVU4EoHEpgzq1VV7AbicfhtW4xC9iM"
PUMP_FUN_FEE_RECIPIENT_PUBKEY = get_pubkey(PUMP_FUN_FEE_RECIPIENT)
PUMP_FUN_ASSOC_TOKEN_ACC_PROG = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL"
PUMP_FUN_ASSOC_TOKEN_ACC_PROG_PUBKEY = get_pubkey(PUMP_FUN_ASSOC_TOKEN_ACC_PROG)
PUMP_FUN_EVENT_AUTHORITY = "Ce6TQqeHC9p8KetsN6JsjHK7UTZk7nasjjnr7XxXp9F1"
PUMP_FUN_EVENT_AUTHORITY_PUBKEY = get_pubkey(PUMP_FUN_EVENT_AUTHORITY)
PUMP_FUN_PROGRAM = "6EF8rrecthR5Dkzon8Nwu78hRvfCKubJ14M5uBEwF6P"
PUMP_FUN_PROGRAM_PUBKEY = get_pubkey(PUMP_FUN_PROGRAM)
PUMP_FUN_SYSTEM_PROGRAM=SYSTEM_PROGRAM
PUMP_FUN_SYSTEM_PROGRAM_PUBKEY = SYSTEM_PROGRAM_PUBKEY
PUMP_FUN_TOKEN_PROGRAM_ID=TOKEN_PROGRAM_ID
PUMP_FUN_TOKEN_PROGRAM_ID_PUBKEY=TOKEN_PROGRAM_ID_PUBKEY
PUMP_FUN_RENT = RENT
PUMP_FUN_RENT_PUBKEY = RENT_PUBKEY

RAYDIUM_POOL_V4_PROGRAM_ID = "675kPX9MHTjS2zt1qfr1NYHuzeLXfQM9H24wFSUt1Mp8"
RAYDIUM_POOL_V4_PROGRAM_ID_PUBKEY=get_pubkey(RAYDIUM_POOL_V4_PROGRAM_ID)
SOL_MINT = "So11111111111111111111111111111111111111112"
SOL_MINT_PUBKEY=get_pubkey(SOL_MINT)


LAMPORTS_PER_SOL = 1_000_000_000
UNIT_PRICE =  1_000_000
UNIT_BUDGET =  100_000
SOL_DECIMALS = 9
